@@ -1,6 +1,7 @@
 import importlib
+import sys
+import traceback
 
-from .forms import UpdateEmailForm, UpdatePhoneNumberForm
 from django.conf import settings
 from django.contrib.auth import get_user_model
 from django.contrib.auth.tokens import default_token_generator
@@ -16,8 +17,9 @@ from rest_framework.response import Response
 from rest_framework.views import APIView
 from rest_framework_simplejwt.tokens import RefreshToken
 
+from .forms import UpdateEmailForm, UpdatePhoneNumberForm
 from .forms import VerifyPhoneForm
-from .serializers import LogoutSerializer, PasswordResetSerializer, UpdateUserDataSerializer, RegisterSerializer, \
+from .serializers import LogoutSerializer, PasswordResetSerializer, RegisterSerializer, \
     LoginSerializer, ChangePasswordSerializer
 from .utils import account_activation_token, send_mail_confirmation
 from .verify_phone import VerifyPhone
@@ -26,34 +28,41 @@ UserModel = get_user_model()
 
 
 class UserSignupAPIView(APIView):
-    def get_form_class(self):
-        form_class = getattr(settings, "REGISTER_FORM", 'dj_accounts.forms.UserCreationForm')
-        if type(form_class) is str:
-            form_class_split = form_class.split('.')
-            class_name = form_class_split[-1:][0]
-            module_name = form_class_split[:-1]
-            return getattr(importlib.import_module('.'.join(module_name)), class_name)
-        else:
-            return form_class
+    access_token = None
+    refresh_token = None
+    token = None
+    user = None
+    authentication_classes = []
+    permission_classes = []
 
     def post(self, request, *args, **kwargs):
-        form = self.get_form_class()(data=request.data)
-        if form.is_valid():
-            self.user = form.save()
-            print(self.user)
+        serializer = RegisterSerializer(data=request.data)
+        if serializer.is_valid():
+            self.user = serializer.save()
+
             try:
                 send_mail_confirmation(request, self.user)
+            except Exception as e:
+                parts = ["Traceback (most recent call last):\n"]
+                parts.extend(traceback.format_stack(limit=25)[:-2])
+                parts.extend(traceback.format_exception(*sys.exc_info())[1:])
+                print("".join(parts))
+
+            try:
                 VerifyPhone().send(self.user.phone)
             except Exception as e:
-                print(e)
-            refresh = RefreshToken.for_user(self.user)
+                parts = ["Traceback (most recent call last):\n"]
+                parts.extend(traceback.format_stack(limit=25)[:-2])
+                parts.extend(traceback.format_exception(*sys.exc_info())[1:])
+                print("".join(parts))
 
+            refresh = RefreshToken.for_user(self.user)
             return Response({
                 "access_token": str(refresh.access_token),
                 "refresh_token": str(refresh)
             }, status=status.HTTP_201_CREATED)
 
-        return Response(form.errors, status=status.HTTP_422_UNPROCESSABLE_ENTITY)
+        return Response(serializer.errors, status=status.HTTP_422_UNPROCESSABLE_ENTITY)
 
 
 class LoginAPIView(APIView):
@@ -130,8 +139,6 @@ class PasswordResetAPIView(APIView):
         return Response(serializer.errors, status=status.HTTP_422_UNPROCESSABLE_ENTITY)
 
 
-# phone verification
-
 class VerifyPhoneAPIView(APIView):
     permission_classes = [IsAuthenticated, ]
 
@@ -151,14 +158,28 @@ class ResendPhoneConfirmationAPIView(APIView):
     permission_classes = (IsAuthenticated,)
 
     def get(self, request, *args, **kwargs):
-        VerifyPhone().send(request.user.phone)
+        try:
+            VerifyPhone().send(request.user.phone)
+        except Exception as e:
+            parts = ["Traceback (most recent call last):\n"]
+            parts.extend(traceback.format_stack(limit=25)[:-2])
+            parts.extend(traceback.format_exception(*sys.exc_info())[1:])
+            print("".join(parts))
+
         return Response({"message": _('Code was resent successfully.')}, status=status.HTTP_200_OK)
 
 
 # email verification
 class ResendEmailConfirmationLinkAPIView(APIView):
     def get(self, request, *args, **kwargs):
-        send_mail_confirmation(request, request.user)
+        try:
+            send_mail_confirmation(request, request.user)
+        except Exception as e:
+            parts = ["Traceback (most recent call last):\n"]
+            parts.extend(traceback.format_stack(limit=25)[:-2])
+            parts.extend(traceback.format_exception(*sys.exc_info())[1:])
+            print("".join(parts))
+
         return Response({"message": _('Email activation link resent successfully')})
 
 
@@ -177,14 +198,19 @@ class VerifyEmailAPIView(APIView):
         return Response({"message": _('Email was verified successfully.')}, status=status.HTTP_200_OK)
 
 
-# user profile
 class UpdateProfileAPIView(APIView):
     """
     An endpoint for changing User Profile Data.
     """
 
     def get_serializer_class(self):
-        return getattr(settings, "PROFILE_SERIALIZER", UpdateUserDataSerializer)
+        serializer_class = getattr(settings, "PROFILE_SERIALIZER", 'dj_accounts.serializer.UpdateUserDataSerializer')
+        if type(serializer_class) is str:
+            form_class_split = serializer_class.split('.')
+            class_name = form_class_split[-1:][0]
+            module_name = form_class_split[:-1]
+            return getattr(importlib.import_module('.'.join(module_name)), class_name)
+        return serializer_class
 
     permission_classes = (IsAuthenticated,)
 
